@@ -72,25 +72,25 @@ class StandardizedPoint(TypedDict):
 def standardized_raw(
     company_identifiers: CompanyIdentifiers = [],
     metrics: Sequence[str] = [],
-    start_year: int = None,
+    start_year: Optional[int] = None,
     start_period: PeriodArgument = None,
-    end_year: int = None,
+    end_year: Optional[int] = None,
     end_period: PeriodArgument = None,
     entire_universe=False,
-    accession_id: int = None,
+    accession_id: Optional[int] = None,
     point_in_time: bool = False,
     include_trace: bool = False,
-    update_date: date = None,
+    update_date: Optional[date] = None,
     all_history=False,
-    year: int = None,
+    year: Optional[int] = None,
     period: PeriodArgument = None,
-    period_type: PeriodType = None,
+    period_type: Optional[PeriodType] = None,
     include_preliminary: bool = False,
     use_fiscal_period: bool = False,
     all_face: bool = False,
     all_footnotes: bool = False,
     include_xbrl: bool = False,
-    exclude_errors: bool = True,
+    filing_id: Optional[int] = None,
 ) -> Sequence[StandardizedPoint]:
     """Standardized data.
 
@@ -109,6 +109,7 @@ def standardized_raw(
     :param period_type: Either "annual" or "quarterly"
     :param include_preliminary: Include data from non-XBRL 8-Ks and press releases.
     :param exclude_errors: Run another level of error detections, only works for PIT preliminary
+    :param filing_id: Filing id for which to get data.  corresponds to the filing_id in the objects returned by the filings API.
     :return: A list of dictionaries with keys ['ticker', 'calendar_year', 'calendar_period', 'metric', 'value'].
 
     """
@@ -116,9 +117,10 @@ def standardized_raw(
         bool(company_identifiers),
         bool(entire_universe),
         bool(accession_id),
+        bool(filing_id),
     ].count(True) != 1:
         raise ValueError(
-            "Must pass either company_identifiers and accession id or entire_universe=True"
+            "Must pass either company_identifiers, accession id, filing_id, or entire_universe=True"
         )
     if not any(
         [
@@ -127,13 +129,14 @@ def standardized_raw(
             update_date,
             year,
             accession_id,
+            filing_id,
             all_history,
             period_type,
         ]
     ):
         raise ValueError("Need to specify a period qualifier")
 
-    if accession_id and any(
+    if (accession_id or filing_id) and any(
         [
             company_identifiers,
             start_year,
@@ -146,7 +149,7 @@ def standardized_raw(
         ]
     ):
         raise ValueError(
-            "Accession IDs are specific to a filing, no other qualifiers make sense."
+            "Accession/Filing IDs are specific to a filing, no other qualifiers make sense."
         )
 
     if period is not None:
@@ -183,7 +186,7 @@ def standardized_raw(
             "specifying metrics with all_face or all_footnotes does not make sense"
         )
 
-    if not any([all_face, all_footnotes, metrics]):
+    if not any([all_face, all_footnotes, metrics, filing_id]):
         raise ValueError(
             "need to specify a metrics argument, 'all_face', 'all_foonotes', or a metric"
         )
@@ -227,7 +230,6 @@ def standardized_raw(
             "allFootnotes": all_footnotes,
             "allface": all_face,
             "includeXBRL": include_xbrl,
-            "excludeErrors": exclude_errors,
         },
         "periodParameters": {
             "year": start_year,
@@ -239,6 +241,7 @@ def standardized_raw(
             "periodType": period_type,
             "useFiscalPeriod": use_fiscal_period,
             "accessionID": accession_id,
+            "filingID": filing_id,
         },
         "companiesParameters": {
             "entireUniverse": entire_universe,
@@ -255,19 +258,20 @@ def point_in_time(
     metrics: Sequence[str] = [],
     all_history: bool = False,
     entire_universe: bool = False,
-    start_year: int = None,
+    start_year: Optional[int] = None,
     start_period: PeriodArgument = None,
-    end_year: int = None,
+    end_year: Optional[int] = None,
     end_period: PeriodArgument = None,
-    period_type: PeriodType = None,
+    period_type: Optional[PeriodType] = None,
     use_fiscal_period: bool = False,
     include_preliminary: bool = False,
     all_face: bool = False,
     include_xbrl: bool = True,
-    accession_id: int = None,
+    accession_id: Optional[int] = None,
     include_trace: bool = False,
     set_index: bool = False,
     _point_in_time_mode=True,
+    filing_id: Optional[int] = None,
 ) -> "pd.DataFrame":
     """Point-in-Time Data
 
@@ -282,7 +286,7 @@ def point_in_time(
 
     If the value is revised in subsequent XBRL filings you will see a record for each filing with an incremented revision number.
 
-    :param accession_id: Unique identifier for the filing for which to recieve data.  Pass this to recieve data for one filing.  Same as filing_id in filings objects
+    :param accession_id: Unique identifier for the filing for which to recieve data.  Pass this to recieve data for one filing.  Same as calcbench_id in filings objects
     :param all_face: Retrieve all of the points from the face financials, income/balance/statement of cash flows
     :param all_footnotes: Retrive all of the points from the footnotes to the financials
     :param include_preliminary: Include facts from non-XBRL earnings press-releases and 8-Ks.
@@ -290,6 +294,7 @@ def point_in_time(
     :param include_trace: Include a URL that points to the source document.
     :param set_index: Set a useful index on the returned DataFrame
     :param _point_in_time_mode: DO NOT USE.  For debugging only.
+    :param filing_id: Filing id for which to get data.  corresponds to the filing_id in the objects returned by the filings API.
     :return: DataFrame of facts
 
     Columns:
@@ -361,6 +366,7 @@ def point_in_time(
         accession_id=accession_id,
         include_trace=include_trace,
         include_xbrl=include_xbrl,
+        filing_id=filing_id,
     )
 
     if not data:
@@ -422,7 +428,9 @@ def point_in_time(
             elif period_type == PeriodType.Annual:
                 data["period"] = pd.PeriodIndex(data["fiscal_year"], freq="A")
         data.drop(["fiscal_year", "fiscal_period"], axis=1, inplace=True)
-        data = data.set_index(["ticker", "metric", "period", "revision_number"])
+        data = data.set_index(
+            ["ticker", "metric", "period", "date_reported"]
+        ).sort_index()
     else:
         data = data.sort_values(sort_columns).reset_index(drop=True)
     return data
@@ -431,20 +439,20 @@ def point_in_time(
 def standardized_data(
     company_identifiers: CompanyIdentifiers = [],
     metrics: Sequence[str] = [],
-    start_year: int = None,
+    start_year: Optional[int] = None,
     start_period: PeriodArgument = None,
-    end_year: int = None,
+    end_year: Optional[int] = None,
     end_period: PeriodArgument = None,
     entire_universe: bool = False,
     point_in_time: bool = False,
-    year: int = None,
+    year: Optional[int] = None,
     period: PeriodArgument = None,
     all_history: bool = False,
-    period_type: PeriodType = None,
+    period_type: Optional[PeriodType] = None,
     trace_hyperlinks: bool = False,
     use_fiscal_period: bool = False,
     company_identifier_scheme: CompanyIdentifierScheme = CompanyIdentifierScheme.Ticker,
-    accession_id: int = None,
+    accession_id: Optional[int] = None,
 ) -> "pd.DataFrame":
     """Standardized Data.
 
